from django.contrib.contenttypes.models import ContentType
from django.template import Library
from django.utils.html import mark_safe

from formation.utils import token_processor

register = Library()


@register.simple_tag(takes_context=True)
def debug(context):
    import ipdb;  # noqa
    ipdb.set_trace()


@register.simple_tag(takes_context=True)
def page_token(context, obj, block_id):
    try:
        token = context['form_token']
    except KeyError:
        obj_id = obj.id
        content_type_id = ContentType.objects.get_for_model(obj.__class__).id
        token = token_processor.generate_token(content_type_id, obj_id, block_id)
    return mark_safe(f'<input type="hidden" name="form_token" value="{token}" />')



import re
import unittest

from django.test import Client
from django.urls import reverse

from home.models import HomePage


form_token_regex = b'name="form_token" value="([^"]+)"'

class TestTest(unittest.TestCase):
    def setUp(self):
        self.client = Client()
        self.home = HomePage.objects.get()
        self.process_url = reverse('process-block-form')

    def get_form_token(self):
        response = self.client.get(self.home.url)
        form_token = re.search(form_token_regex, response.content).groups(0)[0].decode('utf-8')
        return form_token

    def test_page_works(self):
        response = self.client.get(self.home.url)
        self.assertEqual(response.status_code, 200)

    def test_valid_post(self):
        form_token = self.get_form_token()

        response = self.client.post(
            self.process_url,
            {'name': 'my-name', 'message': 'my-message', 'form_token': form_token}
        )
        self.assertTrue(response.context.get('form_success'))

    def test_missing_field(self):
        form_token = self.get_form_token()

        response = self.client.post(
            self.process_url,
            {'message': 'my-message', 'form_token': form_token}
        )
        self.assertFalse(response.context.get('form_success'))




from wagtail import hooks
from wagtail.contrib.modeladmin.options import ModelAdmin, modeladmin_register

from .models import ReusableForm
from .views import ReusableFormChooserViewSet


@modeladmin_register
class ReusableFormAdmin(ModelAdmin):
    model = ReusableForm
    menu_icon = 'form'


@hooks.register('register_admin_viewset')
def register_reusable_form_chooser_viewset():
    return ReusableFormChooserViewSet('form_chooser', url_prefix='form-chooser')



from django.utils.translation import gettext_lazy as _
from generic_chooser.widgets import AdminChooser

from .models import ReusableForm


class ReusableFormChooser(AdminChooser):
    choose_one_text = _("Choose a form")
    choose_another_text = _("Choose another form")
    model = ReusableForm
    choose_modal_url_name = 'form_chooser:choose'
    icon = 'form'
